.. _how-to:

=============
How-to guides
=============

How-to guides are recipes that take the user through steps in key subjects.
They are more advanced than tutorials and assume a lot more about what the user
already knows than tutorials do, and unlike documents in the tutorial they can
stand alone.

.. toctree::
   :maxdepth: 1
   :glob:

   code-signing/index
   upgrade-from-v0.2
   access-packaging-metadata
   contribute-code
   contribute-docs
   internal/index
   publishing/index
